@@ -6,6 +6,19 @@ import simplejson
 from pymongo.objectid import ObjectId
 from types import ModuleType
 from itertools import groupby
+import pymongo
+from bson import json_util
+from flask import make_response
+
+def make_json_response(body, status_code=200):
+    resp = make_response(simplejson.dumps(body, default=json_util.default))
+    resp.status_code = status_code
+    resp.mimetype = 'application/json'
+    
+    return resp
+
+def bad_id_response():
+    return make_json_response({'message': 'invalid id'}, 400)
 
 def encode_model(obj):
     """ This is used for converting mongoengine models to JSON """
